@@ -21,21 +21,15 @@ from os_win.tests import test_base
 from os_win.utils.storage.target import iscsi_target_utils as tg_utils
 
 
-class FakeWMIExc(Exception):
-    def __init__(self, hresult=None):
-        excepinfo = [None] * 5 + [hresult]
-        self.com_error = mock.Mock(excepinfo=excepinfo)
-        super(FakeWMIExc, self).__init__()
-
-
 class ISCSITargetUtilsTestCase(test_base.OsWinBaseTestCase):
     @mock.patch.object(tg_utils, 'hostutils')
-    def setUp(self, mock_hostutils):
+    @mock.patch.object(tg_utils.ISCSITargetUtils,
+                       '_ensure_wt_provider_available')
+    def setUp(self, mock_ensure_wt_provider_available, mock_hostutils):
         super(ISCSITargetUtilsTestCase, self).setUp()
 
-        self._mock_wmi.x_wmi = FakeWMIExc
-
         self._tgutils = tg_utils.ISCSITargetUtils()
+        self._tgutils._conn_wmi = mock.Mock()
         self._tgutils._pathutils = mock.Mock()
 
     def test_ensure_wt_provider_unavailable(self):
@@ -201,7 +195,7 @@ class ISCSITargetUtilsTestCase(test_base.OsWinBaseTestCase):
                                            if idmeth_found else [])
 
         wt_idmeth = self._tgutils._get_wt_idmethod(mock.sentinel.initiator,
-                                                 mock.sentinel.target_name)
+                                                   mock.sentinel.target_name)
 
         expected_wt_idmeth = mock_wt_idmeth if idmeth_found else None
         self.assertEqual(expected_wt_idmeth, wt_idmeth)
@@ -216,28 +210,17 @@ class ISCSITargetUtilsTestCase(test_base.OsWinBaseTestCase):
     def test_get_wt_idmethod_not_found(self):
         self._test_get_wt_idmethod(idmeth_found=False)
 
-    def test_set_wmi_obj_attr(self):
-        wmi_obj = mock.Mock()
-        wmi_property_method = wmi_obj.wmi_property
-        wmi_property = wmi_property_method.return_value
-
-        self._tgutils._wmi_obj_set_attr(wmi_obj,
-                                      mock.sentinel.key,
-                                      mock.sentinel.value)
-
-        wmi_property_method.assert_called_once_with(mock.sentinel.key)
-        wmi_property.set.assert_called_once_with(mock.sentinel.value)
-
     def _test_create_iscsi_target_exception(self, target_exists=False,
                                             fail_if_exists=False):
         fake_file_exists_hres = -0x7ff8ffb0
         fake_hres = fake_file_exists_hres if target_exists else 1
         mock_wt_host_cls = self._tgutils._conn_wmi.WT_Host
-        mock_wt_host_cls.NewHost.side_effect = FakeWMIExc(hresult=fake_hres)
+        mock_wt_host_cls.NewHost.side_effect = test_base.FakeWMIExc(
+            hresult=fake_hres)
 
         if target_exists and not fail_if_exists:
             self._tgutils.create_iscsi_target(mock.sentinel.target_name,
-                                            fail_if_exists=fail_if_exists)
+                                              fail_if_exists=fail_if_exists)
         else:
             self.assertRaises(exceptions.ISCSITargetException,
                               self._tgutils.create_iscsi_target,
@@ -260,7 +243,7 @@ class ISCSITargetUtilsTestCase(test_base.OsWinBaseTestCase):
     @mock.patch.object(tg_utils.ISCSITargetUtils, '_get_wt_host')
     def test_delete_iscsi_target_exception(self, mock_get_wt_host):
         mock_wt_host = mock_get_wt_host.return_value
-        mock_wt_host.Delete_.side_effect = FakeWMIExc
+        mock_wt_host.Delete_.side_effect = test_base.FakeWMIExc
 
         self.assertRaises(exceptions.ISCSITargetException,
                           self._tgutils.delete_iscsi_target,
@@ -306,11 +289,9 @@ class ISCSITargetUtilsTestCase(test_base.OsWinBaseTestCase):
         mock_get_wt_host.assert_called_once_with(mock.sentinel.target_name)
 
     @mock.patch.object(tg_utils.ISCSITargetUtils, '_get_wt_host')
-    @mock.patch.object(tg_utils.ISCSITargetUtils, '_wmi_obj_set_attr')
-    def test_set_chap_credentials_exception(self, mock_set_attr,
-                                            mock_get_wt_host):
+    def test_set_chap_credentials_exception(self, mock_get_wt_host):
         mock_wt_host = mock_get_wt_host.return_value
-        mock_wt_host.put.side_effect = FakeWMIExc
+        mock_wt_host.put.side_effect = test_base.FakeWMIExc
 
         self.assertRaises(exceptions.ISCSITargetException,
                           self._tgutils.set_chap_credentials,
@@ -318,21 +299,20 @@ class ISCSITargetUtilsTestCase(test_base.OsWinBaseTestCase):
                           mock.sentinel.chap_username,
                           mock.sentinel.chap_password)
 
-        expected_fields = dict(EnableCHAP=True,
-                               CHAPUserName=mock.sentinel.chap_username,
-                               CHAPSecret=mock.sentinel.chap_password)
-        expected_setattr_calls = [mock.call(mock_wt_host, key, val)
-                                  for key, val in expected_fields.items()]
-        mock_set_attr.assert_has_calls(expected_setattr_calls,
-                                       any_order=True)
         mock_get_wt_host.assert_called_once_with(mock.sentinel.target_name)
+        self.assertTrue(mock_wt_host.EnableCHAP),
+        self.assertEqual(mock.sentinel.chap_username,
+                         mock_wt_host.CHAPUserName)
+        self.assertEqual(mock.sentinel.chap_password,
+                         mock_wt_host.CHAPSecret)
+        mock_wt_host.put.assert_called_once_with()
 
     @mock.patch.object(tg_utils.ISCSITargetUtils, '_get_wt_idmethod')
     def test_associate_initiator_exception(self, mock_get_wtidmethod):
         mock_get_wtidmethod.return_value = None
         mock_wt_idmeth_cls = self._tgutils._conn_wmi.WT_IDMethod
         mock_wt_idmetod = mock_wt_idmeth_cls.new.return_value
-        mock_wt_idmetod.put.side_effect = FakeWMIExc
+        mock_wt_idmetod.put.side_effect = test_base.FakeWMIExc
 
         self.assertRaises(exceptions.ISCSITargetException,
                           self._tgutils.associate_initiator_with_iscsi_target,
@@ -358,7 +338,7 @@ class ISCSITargetUtilsTestCase(test_base.OsWinBaseTestCase):
     @mock.patch.object(tg_utils.ISCSITargetUtils, '_get_wt_idmethod')
     def test_deassociate_initiator_exception(self, mock_get_wtidmethod):
         mock_wt_idmetod = mock_get_wtidmethod.return_value
-        mock_wt_idmetod.Delete_.side_effect = FakeWMIExc
+        mock_wt_idmetod.Delete_.side_effect = test_base.FakeWMIExc
 
         self.assertRaises(exceptions.ISCSITargetException,
                           self._tgutils.deassociate_initiator,
@@ -369,7 +349,7 @@ class ISCSITargetUtilsTestCase(test_base.OsWinBaseTestCase):
 
     def test_create_wt_disk_exception(self):
         mock_wt_disk_cls = self._tgutils._conn_wmi.WT_Disk
-        mock_wt_disk_cls.NewWTDisk.side_effect = FakeWMIExc
+        mock_wt_disk_cls.NewWTDisk.side_effect = test_base.FakeWMIExc
 
         self.assertRaises(exceptions.ISCSITargetException,
                           self._tgutils.create_wt_disk,
@@ -383,7 +363,7 @@ class ISCSITargetUtilsTestCase(test_base.OsWinBaseTestCase):
 
     def test_import_wt_disk_exception(self):
         mock_wt_disk_cls = self._tgutils._conn_wmi.WT_Disk
-        mock_wt_disk_cls.ImportWTDisk.side_effect = FakeWMIExc
+        mock_wt_disk_cls.ImportWTDisk.side_effect = test_base.FakeWMIExc
 
         self.assertRaises(exceptions.ISCSITargetException,
                           self._tgutils.import_wt_disk,
@@ -396,7 +376,7 @@ class ISCSITargetUtilsTestCase(test_base.OsWinBaseTestCase):
     @mock.patch.object(tg_utils.ISCSITargetUtils, '_get_wt_disk')
     def test_change_wt_disk_status_exception(self, mock_get_wt_disk):
         mock_wt_disk = mock_get_wt_disk.return_value
-        mock_wt_disk.put.side_effect = FakeWMIExc
+        mock_wt_disk.put.side_effect = test_base.FakeWMIExc
         wt_disk_enabled = True
 
         self.assertRaises(exceptions.ISCSITargetException,
@@ -410,7 +390,7 @@ class ISCSITargetUtilsTestCase(test_base.OsWinBaseTestCase):
     @mock.patch.object(tg_utils.ISCSITargetUtils, '_get_wt_disk')
     def test_remove_wt_disk_exception(self, mock_get_wt_disk):
         mock_wt_disk = mock_get_wt_disk.return_value
-        mock_wt_disk.Delete_.side_effect = FakeWMIExc
+        mock_wt_disk.Delete_.side_effect = test_base.FakeWMIExc
 
         self.assertRaises(exceptions.ISCSITargetException,
                           self._tgutils.remove_wt_disk,
@@ -422,7 +402,7 @@ class ISCSITargetUtilsTestCase(test_base.OsWinBaseTestCase):
     @mock.patch.object(tg_utils.ISCSITargetUtils, '_get_wt_disk')
     def test_extend_wt_disk_exception(self, mock_get_wt_disk):
         mock_wt_disk = mock_get_wt_disk.return_value
-        mock_wt_disk.Extend.side_effect = FakeWMIExc
+        mock_wt_disk.Extend.side_effect = test_base.FakeWMIExc
 
         self.assertRaises(exceptions.ISCSITargetException,
                           self._tgutils.extend_wt_disk,
@@ -439,7 +419,7 @@ class ISCSITargetUtilsTestCase(test_base.OsWinBaseTestCase):
                                           mock_get_wt_host):
         mock_wt_disk = mock_get_wt_disk.return_value
         mock_wt_host = mock_get_wt_host.return_value
-        mock_wt_host.AddWTDisk.side_effect = FakeWMIExc
+        mock_wt_host.AddWTDisk.side_effect = test_base.FakeWMIExc
 
         self.assertRaises(exceptions.ISCSITargetException,
                           self._tgutils.add_disk_to_target,
@@ -454,7 +434,7 @@ class ISCSITargetUtilsTestCase(test_base.OsWinBaseTestCase):
     def test_create_snapshot_exception(self, mock_get_wt_disk):
         mock_wt_disk = mock_get_wt_disk.return_value
         mock_wt_snap = mock.Mock()
-        mock_wt_snap.put.side_effect = FakeWMIExc
+        mock_wt_snap.put.side_effect = test_base.FakeWMIExc
         mock_wt_snap_cls = self._tgutils._conn_wmi.WT_Snapshot
         mock_wt_snap_cls.return_value = [mock_wt_snap]
         mock_wt_snap_cls.Create.return_value = [mock.sentinel.snap_id]
@@ -472,7 +452,7 @@ class ISCSITargetUtilsTestCase(test_base.OsWinBaseTestCase):
     @mock.patch.object(tg_utils.ISCSITargetUtils, '_get_wt_snapshot')
     def test_delete_snapshot_exception(self, mock_get_wt_snap):
         mock_wt_snap = mock_get_wt_snap.return_value
-        mock_wt_snap.Delete_.side_effect = FakeWMIExc
+        mock_wt_snap.Delete_.side_effect = test_base.FakeWMIExc
 
         self.assertRaises(exceptions.ISCSITargetException,
                           self._tgutils.delete_snapshot,
@@ -486,7 +466,7 @@ class ISCSITargetUtilsTestCase(test_base.OsWinBaseTestCase):
         mock_wt_disk_cls = self._tgutils._conn_wmi.WT_Disk
         mock_wt_disk = mock.Mock()
         mock_wt_disk_cls.return_value = [mock_wt_disk]
-        mock_wt_disk.Delete_.side_effect = FakeWMIExc
+        mock_wt_disk.Delete_.side_effect = test_base.FakeWMIExc
         mock_wt_snap = mock_get_wt_snap.return_value
         mock_wt_snap.Export.return_value = [mock.sentinel.wt_disk_id]
 
