@@ -20,14 +20,12 @@ Based on the "root/virtualization/v2" namespace available starting with
 Hyper-V Server / Windows Server 2012.
 """
 
-import sys
+import functools
 import time
 import uuid
 
-if sys.platform == 'win32':
-    import wmi
-
-from oslo_config import cfg
+from eventlet import patcher
+from eventlet import tpool
 from oslo_log import log as logging
 from oslo_utils import uuidutils
 import six
@@ -42,7 +40,6 @@ from os_win.utils import baseutils
 from os_win.utils import jobutils
 from os_win.utils import pathutils
 
-CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
 
@@ -135,14 +132,17 @@ class VMUtils(baseutils.BaseUtilsVirt):
         for vs in self._conn.Msvm_VirtualSystemSettingData(
                 ['ElementName', 'Notes'],
                 VirtualSystemType=self._VIRTUAL_SYSTEM_TYPE_REALIZED):
-            if vs.Notes is not None:
+            vs_notes = vs.Notes
+            vs_name = vs.ElementName
+            if vs_notes is not None and vs_name:
                 instance_notes.append(
-                    (vs.ElementName, [v for v in vs.Notes if v]))
+                    (vs_name, [v for v in vs_notes if v]))
 
         return instance_notes
 
     def list_instances(self):
         """Return the names of all the instances known to Hyper-V."""
+
         return [v.ElementName for v in
                 self._conn.Msvm_VirtualSystemSettingData(
                     ['ElementName'],
@@ -177,7 +177,8 @@ class VMUtils(baseutils.BaseUtilsVirt):
         # considering that in all the non mappable states the instance
         # is running.
         enabled_state = self._enabled_states_map.get(si.EnabledState,
-            constants.HYPERV_VM_STATE_ENABLED)
+                                                     constants.
+                                                     HYPERV_VM_STATE_ENABLED)
 
         summary_info_dict = {'NumberOfProcessors': si.NumberOfProcessors,
                              'EnabledState': enabled_state,
@@ -365,8 +366,8 @@ class VMUtils(baseutils.BaseUtilsVirt):
             self._conn, self._RESOURCE_ALLOC_SETTING_DATA_CLASS,
             element_instance_id=vmsettings.InstanceID)
         ide_ctrls = [r for r in rasds
-                     if r.ResourceSubType == self._IDE_CTRL_RES_SUB_TYPE
-                     and r.Address == str(ctrller_addr)]
+                     if r.ResourceSubType == self._IDE_CTRL_RES_SUB_TYPE and
+                     r.Address == str(ctrller_addr)]
 
         return ide_ctrls[0].path_() if ide_ctrls else None
 
@@ -492,7 +493,7 @@ class VMUtils(baseutils.BaseUtilsVirt):
         physical_disks = self.get_vm_disks(vm_name)[1]
         for diskdrive in physical_disks:
             mapping[diskdrive.ElementName] = dict(
-                resource_path=diskdrive.Path_(),
+                resource_path=diskdrive.path_(),
                 mounted_disk_path=diskdrive.HostResource[0])
         return mapping
 
@@ -518,7 +519,7 @@ class VMUtils(baseutils.BaseUtilsVirt):
                 if (disk_resource.HostResource and
                         disk_resource.HostResource[0] != mounted_disk_path):
                     LOG.debug('Updating disk host resource "%(old)s" to '
-                                '"%(new)s"' %
+                              '"%(new)s"' %
                               {'old': disk_resource.HostResource[0],
                                'new': mounted_disk_path})
                     disk_resource.HostResource = [mounted_disk_path]
@@ -580,6 +581,7 @@ class VMUtils(baseutils.BaseUtilsVirt):
 
     def set_vm_state(self, vm_name, req_state):
         """Set the desired state of the VM."""
+
         vm = self._lookup_vm_check(vm_name, as_vssd=False)
         (job_path,
          ret_val) = vm.RequestStateChange(self._vm_power_states_map[req_state])
@@ -795,10 +797,12 @@ class VMUtils(baseutils.BaseUtilsVirt):
 
     def get_active_instances(self):
         """Return the names of all the active instances known to Hyper-V."""
+
         vm_names = self.list_instances()
         vms = [self._lookup_vm(vm_name, as_vssd=False) for vm_name in vm_names]
         active_vm_names = [v.ElementName for v in vms
-            if v.EnabledState == constants.HYPERV_VM_STATE_ENABLED]
+                           if v.EnabledState ==
+                           constants.HYPERV_VM_STATE_ENABLED]
 
         return active_vm_names
 
@@ -815,11 +819,22 @@ class VMUtils(baseutils.BaseUtilsVirt):
                                                             fields=[field])
 
         def _handle_events(callback):
+            if patcher.is_monkey_patched('thread'):
+                # Retrieve one by one all the events that occurred in
+                # the checked interval.
+                #
+                # We use eventlet.tpool for retrieving the events in
+                # order to avoid issues caused by greenthread/thread
+                # communication. Note that PyMI must use the unpatched
+                # threading module.
+                listen = functools.partial(tpool.execute, listener,
+                                           event_timeout)
+            else:
+                listen = functools.partial(listener, event_timeout)
+
             while True:
                 try:
-                    # Retrieve one by one all the events that occurred in
-                    # the checked interval.
-                    event = listener(event_timeout)
+                    event = listen()
 
                     vm_name = event.ElementName
                     vm_state = event.EnabledState
@@ -835,7 +850,7 @@ class VMUtils(baseutils.BaseUtilsVirt):
                         LOG.exception(err_msg,
                                       dict(vm_name=vm_name,
                                            vm_power_state=vm_power_state))
-                except wmi.x_wmi_timed_out:
+                except exceptions.x_wmi_timed_out:
                     pass
                 except Exception:
                     LOG.exception(
@@ -857,15 +872,16 @@ class VMUtils(baseutils.BaseUtilsVirt):
                                     object transitioned into one of those
                                     states.
         """
+
         query = ("SELECT %(field)s, TargetInstance "
                  "FROM __InstanceModificationEvent "
                  "WITHIN %(timeframe)s "
                  "WHERE TargetInstance ISA '%(class)s' "
                  "AND TargetInstance.%(field)s != "
                  "PreviousInstance.%(field)s" %
-                    {'class': cls,
-                     'field': field,
-                     'timeframe': timeframe})
+                 {'class': cls,
+                  'field': field,
+                  'timeframe': timeframe})
         if filtered_states:
             checks = ["TargetInstance.%s = '%s'" % (field, state)
                       for state in filtered_states]
@@ -874,7 +890,8 @@ class VMUtils(baseutils.BaseUtilsVirt):
 
     def _get_instance_notes(self, vm_name):
         vmsettings = self._lookup_vm_check(vm_name)
-        return [note for note in vmsettings.Notes if note]
+        vm_notes = vmsettings.Notes or []
+        return [note for note in vm_notes if note]
 
     def get_instance_uuid(self, vm_name):
         instance_notes = self._get_instance_notes(vm_name)
@@ -911,6 +928,7 @@ class VMUtils(baseutils.BaseUtilsVirt):
                                  Authority for Secure Boot. Only Linux
                                  guests require this CA.
         """
+
         vs_data = self._lookup_vm_check(vm_name)
         self._set_secure_boot(vs_data, msft_ca_required)
         self._modify_virtual_system(vs_data)
@@ -968,7 +986,7 @@ class VMUtils(baseutils.BaseUtilsVirt):
 
     def _set_boot_order_gen2(self, vm_name, device_boot_order):
         new_boot_order = [(self._drive_to_boot_source(device))
-                           for device in device_boot_order if device]
+                          for device in device_boot_order if device]
 
         vssd = self._lookup_vm_check(vm_name)
         old_boot_order = vssd.BootSourceOrder
@@ -986,10 +1004,12 @@ class VMUtils(baseutils.BaseUtilsVirt):
 
     def vm_gen_supports_remotefx(self, vm_gen):
         """RemoteFX is supported only for generation 1 virtual machines
+
         on Windows 8 / Windows Server 2012 and 2012R2.
 
         :returns: True if the given vm_gen is 1, False otherwise
         """
+
         return vm_gen == constants.VM_GEN_1
 
     def _validate_remotefx_params(self, monitor_count, max_resolution,
@@ -1004,10 +1024,10 @@ class VMUtils(baseutils.BaseUtilsVirt):
                 _("Unsuported RemoteFX monitor count: %(count)s for "
                   "this resolution %(res)s. Hyper-V supports a maximum "
                   "of %(max_monitors)s monitors for this resolution.")
-                  % {'count': monitor_count,
-                     'res': max_resolution,
-                     'max_monitors': self._remotefx_max_monitors_map[
-                        max_resolution]})
+                % {'count': monitor_count,
+                   'res': max_resolution,
+                   'max_monitors':
+                   self._remotefx_max_monitors_map[max_resolution]})
 
     def _add_3d_display_controller(self, vm, monitor_count,
                                    max_resolution, vram_bytes=None):
@@ -1051,3 +1071,6 @@ class VMUtils(baseutils.BaseUtilsVirt):
 
     def _vm_has_s3_controller(self, vm_name):
         return True
+
+    def is_secure_vm(self, instance_name):
+        return False
